quscope.image\_processing.quantum\_segmentation
===============================================

.. automodule:: quscope.image_processing.quantum_segmentation

   
   .. rubric:: Functions

   .. autosummary::
   
      apply_grovers_algorithm
      calculate_optimal_iterations
      create_custom_oracle
      create_edge_oracle
      create_pattern_oracle
      create_region_oracle
      create_threshold_oracle
      interpret_results
      optimize_circuit
      segment_image
   
   .. rubric:: Classes

   .. autosummary::
   
      SegmentationMethod
      SegmentationResult
   
   .. rubric:: Exceptions

   .. autosummary::
   
      OracleConstructionError
      SegmentationError
   